# Register

Please complete the form below to create a new account or sign in to your existing account.

## Account details

Title
First name
Last name
Phone
Email
Ensure this value is correct.
Password
Confirm password
This account is for a UK school.

## Account address

Enter a BFPO address?
Country
Postcode
Results
School name
Address line 1
Address line 2
Town/city
County

## School Details

Education type
Your position
Number of pupils
Did the local bookseller who visits your school recommend us to you?

## Mailing options

Receive our catalogue by post
Receive offers by email
Receive offers by post from other carefully selected companies

Please correct the following errors:

By creating an account or signing in, you agree to the Book People’s Terms & Conditions, Terms & Conditions of Credit and Privacy Policy.